@@ -27,7 +27,7 @@
 #include <QMessageBox>
 #include <QDebug>
 
-using namespace LxQt;
+using namespace LXQt;
 
 Notification::Notification(const QString& summary, QObject* parent) :
     QObject(parent),
@@ -158,7 +158,8 @@ void NotificationPrivate::setActions(QStringList actions, int defaultAction)
 {
     mActions.clear();
     mDefaultAction = defaultAction;
-    for (int ix = 0; ix < actions.size(); ix++)
+    const int N = actions.size();
+    for (int ix = 0; ix < N; ix++)
     {
         if (ix == defaultAction)
             mActions.append("default");
@@ -189,7 +190,7 @@ void NotificationPrivate::handleAction(uint id, QString key)
     else
         keyId = key.toInt(&ok);
 
-    if (ok && key >= 0)
+    if (ok && keyId >= 0)
         emit q->actionActivated(keyId);
 }
 
