@@ -35,7 +35,7 @@
 #include <QLibrary>
 #include <QDebug>
 
-using namespace LxQt;
+using namespace LXQt;
 
 /************************************************
 
@@ -72,12 +72,11 @@ bool PluginInfo::isValid() const
  ************************************************/
 QLibrary* PluginInfo::loadLibrary(const QString& libDir) const
 {
-    QString baseName, path;
-    QFileInfo fi = QFileInfo(fileName());
-    path = fi.canonicalPath();
-    baseName = value("X-LxQt-Library", fi.completeBaseName()).toString();
+    const QFileInfo fi = QFileInfo(fileName());
+    const QString path = fi.canonicalPath();
+    const QString baseName = value("X-LXQt-Library", fi.completeBaseName()).toString();
 
-    QString soPath = QDir(libDir).filePath(QString("lib%2.so").arg(baseName));
+    const QString soPath = QDir(libDir).filePath(QString("lib%2.so").arg(baseName));
     QLibrary* library = new QLibrary(soPath);
 
     if (!library->load())
@@ -87,7 +86,7 @@ QLibrary* PluginInfo::loadLibrary(const QString& libDir) const
         return 0;
     }
 
-    QString locale = QLocale::system().name();
+    const QString locale = QLocale::system().name();
     QTranslator* translator = new QTranslator(library);
 
     translator->load(QString("%1/%2/%2_%3.qm").arg(path, baseName, locale));
@@ -105,11 +104,11 @@ PluginInfoList PluginInfo::search(const QStringList& desktopFilesDirs, const QSt
     QList<PluginInfo> res;
     QSet<QString> processed;
 
-    foreach (QString desktopFilesDir, desktopFilesDirs)
+    foreach (const QString &desktopFilesDir, desktopFilesDirs)
     {
-        QDir dir(desktopFilesDir);
-        QFileInfoList files = dir.entryInfoList(QStringList(nameFilter), QDir::Files | QDir::Readable);
-        foreach (QFileInfo file, files)
+        const QDir dir(desktopFilesDir);
+        const QFileInfoList files = dir.entryInfoList(QStringList(nameFilter), QDir::Files | QDir::Readable);
+        foreach (const QFileInfo &file, files)
         {
             if (processed.contains(file.fileName()))
                 continue;
@@ -139,7 +138,7 @@ PluginInfoList PluginInfo::search(const QString& desktopFilesDir, const QString&
 /************************************************
 
  ************************************************/
-QDebug operator<<(QDebug dbg, const LxQt::PluginInfo &pluginInfo)
+QDebug operator<<(QDebug dbg, const LXQt::PluginInfo &pluginInfo)
 {
     dbg.nospace() << QString("%1").arg(pluginInfo.id());
     return dbg.space();
@@ -149,7 +148,7 @@ QDebug operator<<(QDebug dbg, const LxQt::PluginInfo &pluginInfo)
 /************************************************
 
  ************************************************/
-QDebug operator<<(QDebug dbg, const LxQt::PluginInfo * const pluginInfo)
+QDebug operator<<(QDebug dbg, const LXQt::PluginInfo * const pluginInfo)
 {
     return operator<<(dbg, *pluginInfo);
 }
